summaryrefslogtreecommitdiffstats
path: root/src/combobutton.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/combobutton.h')
-rwxr-xr-xsrc/combobutton.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/combobutton.h b/src/combobutton.h
index 73d87d3..d96daaa 100755
--- a/src/combobutton.h
+++ b/src/combobutton.h
@@ -26,10 +26,10 @@ public:
/**
* Constructor
* @param tqparent The tqparent widget
* @param name The name of the file list
*/
- ComboButton( TQWidget *tqparent, const char *name = 0 );
+ ComboButton( TQWidget *parent, const char *name = 0 );
/**
* Destructor
@@ -26,10 +26,10 @@ public:
/**
* Constructor
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
* @param name The name of the file list
*/